/*******************************************************************************
* File Name: ISR_INT0.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <ISR_INT0.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ISR_INT0_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: ISR_INT0_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_INT0_Start(void)
{
    /* For all we know the interrupt is active. */
    ISR_INT0_Disable();

    /* Set the ISR to point to the ISR_INT0 Interrupt. */
    ISR_INT0_SetVector(ISR_INT0_Interrupt);

    /* Set the priority. */
    ISR_INT0_SetPriority(ISR_INT0_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_INT0_Enable();
}

/*******************************************************************************
* Function Name: ISR_INT0_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_INT0_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ISR_INT0_Disable();

    /* Set the ISR to point to the ISR_INT0 Interrupt. */
    ISR_INT0_SetVector(address);

    /* Set the priority. */
    ISR_INT0_SetPriority(ISR_INT0_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_INT0_Enable();
}

/*******************************************************************************
* Function Name: ISR_INT0_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_INT0_Stop(void) 
{
    /* Disable this interrupt. */
    ISR_INT0_Disable();

    /* Set the ISR to point to the passive one. */
    ISR_INT0_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: ISR_INT0_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for ISR_INT0.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(ISR_INT0_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ISR_INT0_Interrupt` */

    /* `#END` */
}

/*******************************************************************************
* Function Name: ISR_INT0_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ISR_INT0_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use ISR_INT0_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + ISR_INT0__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: ISR_INT0_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress ISR_INT0_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + ISR_INT0__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: ISR_INT0_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling ISR_INT0_Start
*   or ISR_INT0_StartEx will override any effect this method would have had. 
*	This method should only be called after ISR_INT0_Start or 
*	ISR_INT0_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_SetPriority(uint8 priority) 
{
    *ISR_INT0_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: ISR_INT0_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 ISR_INT0_GetPriority(void) 
{
    uint8 priority;


    priority = *ISR_INT0_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: ISR_INT0_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_Enable(void) 
{
    /* Enable the general interrupt. */
    *ISR_INT0_INTC_SET_EN = ISR_INT0__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_INT0_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 ISR_INT0_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*ISR_INT0_INTC_SET_EN & ISR_INT0__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: ISR_INT0_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_Disable(void) 
{
    /* Disable the general interrupt. */
    *ISR_INT0_INTC_CLR_EN = ISR_INT0__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_INT0_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_SetPending(void) 
{
    *ISR_INT0_INTC_SET_PD = ISR_INT0__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_INT0_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_INT0_ClearPending(void) 
{
    *ISR_INT0_INTC_CLR_PD = ISR_INT0__INTC_MASK;
}
