/*******************************************************************************
* File Name: P3_4.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "P3_4.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 P3_4__PORT == 15 && (P3_4__MASK & 0xC0))

/*******************************************************************************
* Function Name: P3_4_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void P3_4_Write(uint8 value) 
{
    uint8 staticBits = P3_4_DR & ~P3_4_MASK;
    P3_4_DR = staticBits | ((value << P3_4_SHIFT) & P3_4_MASK);
}


/*******************************************************************************
* Function Name: P3_4_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void P3_4_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(P3_4_0, mode);
}


/*******************************************************************************
* Function Name: P3_4_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro P3_4_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 P3_4_Read(void) 
{
    return (P3_4_PS & P3_4_MASK) >> P3_4_SHIFT;
}


/*******************************************************************************
* Function Name: P3_4_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 P3_4_ReadDataReg(void) 
{
    return (P3_4_DR & P3_4_MASK) >> P3_4_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(P3_4_INTSTAT) 

    /*******************************************************************************
    * Function Name: P3_4_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 P3_4_ClearInterrupt(void) 
    {
        return (P3_4_INTSTAT & P3_4_MASK) >> P3_4_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
