/*******************************************************************************
* File Name: PSEN.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "PSEN.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 PSEN__PORT == 15 && (PSEN__MASK & 0xC0))

/*******************************************************************************
* Function Name: PSEN_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void PSEN_Write(uint8 value) 
{
    uint8 staticBits = PSEN_DR & ~PSEN_MASK;
    PSEN_DR = staticBits | ((value << PSEN_SHIFT) & PSEN_MASK);
}


/*******************************************************************************
* Function Name: PSEN_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void PSEN_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PSEN_0, mode);
}


/*******************************************************************************
* Function Name: PSEN_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PSEN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PSEN_Read(void) 
{
    return (PSEN_PS & PSEN_MASK) >> PSEN_SHIFT;
}


/*******************************************************************************
* Function Name: PSEN_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PSEN_ReadDataReg(void) 
{
    return (PSEN_DR & PSEN_MASK) >> PSEN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PSEN_INTSTAT) 

    /*******************************************************************************
    * Function Name: PSEN_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PSEN_ClearInterrupt(void) 
    {
        return (PSEN_INTSTAT & PSEN_MASK) >> PSEN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
