/*******************************************************************************
* File Name: PWM_0_PM.c
* Version 2.20
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PWM_0.h"

static PWM_0_backupStruct PWM_0_backup;


/*******************************************************************************
* Function Name: PWM_0_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_0_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void PWM_0_SaveConfig(void) 
{
    
    #if(!PWM_0_UsingFixedFunction)
        #if (CY_PSOC5A)
            PWM_0_backup.PWMUdb = PWM_0_ReadCounter();
            PWM_0_backup.PWMPeriod = PWM_0_ReadPeriod();
            #if (PWM_0_UseStatus)
                PWM_0_backup.InterruptMaskValue = PWM_0_STATUS_MASK;
            #endif /* (PWM_0_UseStatus) */
            
            #if(PWM_0_UseOneCompareMode)
                PWM_0_backup.PWMCompareValue = PWM_0_ReadCompare();
            #else
                PWM_0_backup.PWMCompareValue1 = PWM_0_ReadCompare1();
                PWM_0_backup.PWMCompareValue2 = PWM_0_ReadCompare2();
            #endif /* (PWM_0_UseOneCompareMode) */
            
           #if(PWM_0_DeadBandUsed)
                PWM_0_backup.PWMdeadBandValue = PWM_0_ReadDeadTime();
            #endif /* (PWM_0_DeadBandUsed) */
          
            #if ( PWM_0_KillModeMinTime)
                PWM_0_backup.PWMKillCounterPeriod = PWM_0_ReadKillTime();
            #endif /* ( PWM_0_KillModeMinTime) */
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            #if(!PWM_0_PWMModeIsCenterAligned)
                PWM_0_backup.PWMPeriod = PWM_0_ReadPeriod();
            #endif /* (!PWM_0_PWMModeIsCenterAligned) */
            PWM_0_backup.PWMUdb = PWM_0_ReadCounter();
            #if (PWM_0_UseStatus)
                PWM_0_backup.InterruptMaskValue = PWM_0_STATUS_MASK;
            #endif /* (PWM_0_UseStatus) */
            
            #if(PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_256_CLOCKS || \
                PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_2_4_CLOCKS)
                PWM_0_backup.PWMdeadBandValue = PWM_0_ReadDeadTime();
            #endif /*  deadband count is either 2-4 clocks or 256 clocks */
            
            #if(PWM_0_KillModeMinTime)
                 PWM_0_backup.PWMKillCounterPeriod = PWM_0_ReadKillTime();
            #endif /* (PWM_0_KillModeMinTime) */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(PWM_0_UseControl)
            PWM_0_backup.PWMControlRegister = PWM_0_ReadControlRegister();
        #endif /* (PWM_0_UseControl) */
    #endif  /* (!PWM_0_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PWM_0_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_0_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void PWM_0_RestoreConfig(void) 
{
        #if(!PWM_0_UsingFixedFunction)
            #if (CY_PSOC5A)
                /* Interrupt State Backup for Critical Region*/
                uint8 PWM_0_interruptState;
                /* Enter Critical Region*/
                PWM_0_interruptState = CyEnterCriticalSection();
                #if (PWM_0_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    PWM_0_STATUS_AUX_CTRL |= PWM_0_STATUS_ACTL_INT_EN_MASK;
                    
                    PWM_0_STATUS_MASK = PWM_0_backup.InterruptMaskValue;
                #endif /* (PWM_0_UseStatus) */
                
                #if (PWM_0_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    PWM_0_AUX_CONTROLDP0 |= (PWM_0_AUX_CTRL_FIFO0_CLR);
                #else /* (PWM_0_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    PWM_0_AUX_CONTROLDP0 |= (PWM_0_AUX_CTRL_FIFO0_CLR);
                    PWM_0_AUX_CONTROLDP1 |= (PWM_0_AUX_CTRL_FIFO0_CLR);
                #endif /* (PWM_0_Resolution == 8) */
                /* Exit Critical Region*/
                CyExitCriticalSection(PWM_0_interruptState);
                
                PWM_0_WriteCounter(PWM_0_backup.PWMUdb);
                PWM_0_WritePeriod(PWM_0_backup.PWMPeriod);
                
                #if(PWM_0_UseOneCompareMode)
                    PWM_0_WriteCompare(PWM_0_backup.PWMCompareValue);
                #else
                    PWM_0_WriteCompare1(PWM_0_backup.PWMCompareValue1);
                    PWM_0_WriteCompare2(PWM_0_backup.PWMCompareValue2);
                #endif /* (PWM_0_UseOneCompareMode) */
                
               #if(PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_256_CLOCKS || \
                   PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_2_4_CLOCKS)
                    PWM_0_WriteDeadTime(PWM_0_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
                #if ( PWM_0_KillModeMinTime)
                    PWM_0_WriteKillTime(PWM_0_backup.PWMKillCounterPeriod);
                #endif /* ( PWM_0_KillModeMinTime) */
            #endif /* (CY_PSOC5A) */
            
            #if (CY_PSOC3 || CY_PSOC5LP)
                #if(!PWM_0_PWMModeIsCenterAligned)
                    PWM_0_WritePeriod(PWM_0_backup.PWMPeriod);
                #endif /* (!PWM_0_PWMModeIsCenterAligned) */
                PWM_0_WriteCounter(PWM_0_backup.PWMUdb);
                #if (PWM_0_UseStatus)
                    PWM_0_STATUS_MASK = PWM_0_backup.InterruptMaskValue;
                #endif /* (PWM_0_UseStatus) */
                
                #if(PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_256_CLOCKS || \
                    PWM_0_DeadBandMode == PWM_0__B_PWM__DBM_2_4_CLOCKS)
                    PWM_0_WriteDeadTime(PWM_0_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
                
                #if(PWM_0_KillModeMinTime)
                    PWM_0_WriteKillTime(PWM_0_backup.PWMKillCounterPeriod);
                #endif /* (PWM_0_KillModeMinTime) */
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            
            #if(PWM_0_UseControl)
                PWM_0_WriteControlRegister(PWM_0_backup.PWMControlRegister); 
            #endif /* (PWM_0_UseControl) */
        #endif  /* (!PWM_0_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: PWM_0_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_0_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void PWM_0_Sleep(void) 
{
    #if(PWM_0_UseControl)
        if(PWM_0_CTRL_ENABLE == (PWM_0_CONTROL & PWM_0_CTRL_ENABLE))
        {
            /*Component is enabled */
            PWM_0_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PWM_0_backup.PWMEnableState = 0u;
        }
    #endif /* (PWM_0_UseControl) */
    /* Stop component */
    PWM_0_Stop();
    
    /* Save registers configuration */
    PWM_0_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_0_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_0_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PWM_0_Wakeup(void) 
{
     /* Restore registers values */
    PWM_0_RestoreConfig();
    
    if(PWM_0_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PWM_0_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
